# Null Input

print('''
Where do you want to Organize your Files?
1. Downloads
2. Any Other Location
Enter the Full Path to your Directory [Just Type 'Downloads' for Case 2] ->
''')

path = input()
if not path:
    print(f"None!")
else:
    print(f"Not Null!")

path = None
if not path:
    path = "Downloads"
else:
    path = "Not Downloads"
print(path)


## Conlusion => Unit Testing Successful for nullInput.


# Importing Libraries

import shutil
from pathlib import Path
import os
from os import listdir
from os.path import isfile, join

# Class 'Move Files'
class directoryOrganiser:

    # Constructor
    def __init__(self, path = None):

        # Checking Condition for Default Argument
        if not path:
            
            path = "Downloads"

            # Setting Home Directory Path
            self.homedir = str(Path.home())
            
            # Set the Source Direcory Path [i.e the Downloads Path by DEFAULT]
            self.source = os.path.join(self.homedir, path)
        
        else:

            # Set the Source Direcory Path [when Path isn't Downloads]
            self.source = os.path.join(path)
        
        # Copying All Files Names Present in the Source Directory
        self.all_files = [f for f in listdir(self.source) if isfile(join(self.source, f))]

        ## NOTE - We can Change the "/Downloads" path to any other appropriate path if this script is required to run in that Directory

        # List Containing the files to be Moved
        self.documents = []
        self.pictures = []
        self.musics = []
        self.videos = []
        self.others = []

        # Including All Types of File Extensions Possible

        ## Adding file extension in required places to include that files in that directory
        self.picture_ext = ['.jpeg', '.jpg', '.png', '.bnp', '.tiff', '.gif']
        self.document_ext = ['.txt', '.md', '.pdf', '.doc', '.odt', '.docx', '.xls', '.xlsx', '.csv', '.tex', '.ppt', '.pptx', '.rtf', '.wpd']
        self.music_ext = ['.mp3', '.mpeg', '.wav', '.wma', '.3gp', '.aac', '.wma']
        self.video_ext = ['.mp4', '.avi', '.mkv', '.mov', '.flv']

        ## Adding CAPS Extensions too
        self.picture_ext += [i.upper() for i in self.picture_ext]
        self.document_ext += [i.upper() for i in self.picture_ext]
        self.music_ext += [i.upper() for i in self.music_ext]
        self.video_ext += [i.upper() for i in self.video_ext]

        # Flag if the User wants to Print the Files that are been moved
        self.flag = None

        # Extracting Information about the Files Present
        self.extractingFiles()


    # Function which extracts Information about the Files Present

    def extractingFiles(self):

        # Searching for Files and Categorising
        for files in self.all_files:

            if files.endswith(tuple(self.picture_ext)):
                self.pictures.append(files)
            elif files.endswith(tuple(self.document_ext)):
                self.documents.append(files)
            elif files.endswith(tuple(self.music_ext)):
                self.musics.append(files)
            elif files.endswith(tuple(self.video_ext)):
                self.videos.append(files)
            else:
                self.others.append(files)


    # Display Functions to Print Operation [Show Moved Files]
        
    def show_Moved_Pictures(self):

        #print("Interpreter was Here")
        print(f'{len(self.pictures)} Files moved to Pictures!')
        if self.flag.lower() == 'yes':
            for picture in self.pictures:
                print(picture)


    # Functions Handling the Moving Mechanism

    def move_To_Pictures(self):

        #print("Interpreter was Here")
        destination = os.path.join(self.source, 'Pictures')
        self.checkDirExists(destination)
        print("Moving Pictures ...")
        for picture in self.pictures:
            shutil.move(os.path.join(self.source, picture), destination)
        self.show_Moved_Pictures()


    # Condition to Check if Required Files are Present [for Moving] and are Calling Appropriate Functions

    def checkCondition(self):

        #print("Interpreter was Here")
        self.flag = input("Do you want to Display the File Names? (YES/NO) : ")
        if len(self.pictures) != 0:
            self.move_To_Pictures()
        else:
            print("No Pictures to Move!")

    
    # Check for Existence of a Directory [if it DNE, creates a New One]
    
    def checkDirExists(self, path):

        #print("Interpreter was Here")
        if not os.path.isdir(path):
            os.makedirs(path)

    
# Main Function
def main():
    
    print('''
Where do you want to Organise your Files?
1. Downloads
2. Any Other Location
Enter the Full Path to your Directory [Just Type 'Downloads' for Case 2] ->
    ''')
    path = input()
    moveFilesObject = directoryOrganiser(path)
    #print("Interpreter was Here")
    moveFilesObject.checkCondition()


# Main Method
if __name__ == '__main__':
    main()


# Importing Libraries

import shutil
from pathlib import Path
import os
from os import listdir
from os.path import isfile, join

# Class 'Move Files'
class directoryOrganiser:

    # Constructor
    def __init__(self, path = None):

        # Checking Condition for Default Argument
        if not path:
            
            path = "Downloads"

            # Setting Home Directory Path
            self.homedir = str(Path.home())
            
            # Set the Source Directory Path [i.e the Downloads Path by DEFAULT]
            self.source = os.path.join(self.homedir, path)
        
        else:

            # Set the Source Directory Path [when Path isn't Downloads]
            self.source = os.path.join(path)
        
        # Copying All Files Names Present in the Source Directory
        self.all_files = [f for f in listdir(self.source) if isfile(join(self.source, f))]

        ## NOTE - We can Change the "/Downloads" path to any other appropriate path if this script is required to run in that Directory

        # List Containing the files to be Moved
        self.documents = []
        self.pictures = []
        self.musics = []
        self.videos = []
        self.others = []

        # Including All Types of File Extensions Possible

        ## Adding file extension in required places to include that files in that directory
        self.picture_ext = ['.jpeg', '.jpg', '.png', '.bnp', '.tiff', '.gif']
        self.document_ext = ['.txt', '.md', '.pdf', '.doc', '.odt', '.docx', '.xls', '.xlsx', '.csv', '.tex', '.ppt', '.pptx', '.rtf', '.wpd']
        self.music_ext = ['.mp3', '.mpeg', '.wav', '.wma', '.3gp', '.aac', '.wma']
        self.video_ext = ['.mp4', '.avi', '.mkv', '.mov', '.flv']

        ## Adding CAPS Extensions too
        self.picture_ext += [i.upper() for i in self.picture_ext]
        self.document_ext += [i.upper() for i in self.picture_ext]
        self.music_ext += [i.upper() for i in self.music_ext]
        self.video_ext += [i.upper() for i in self.video_ext]

        # Flag if the User wants to Print the Files that are been moved
        self.flag = None

        # Extracting Information about the Files Present
        self.extractingFiles()


    # Function which extracts Information about the Files Present

    def extractingFiles(self):

        # Searching for Files and Categorising
        for files in self.all_files:

            if files.endswith(tuple(self.picture_ext)):
                self.pictures.append(files)
            elif files.endswith(tuple(self.document_ext)):
                self.documents.append(files)
            elif files.endswith(tuple(self.music_ext)):
                self.musics.append(files)
            elif files.endswith(tuple(self.video_ext)):
                self.videos.append(files)
            else:
                self.others.append(files)


    # Display Functions to Print Operation(s) [Show Moved Files] [Flag]
        
    def show_Moved_Documents(self):

        print(f"{len(self.documents)} Files moved to Documents!")
        if self.flag.lower() == 'yes':
            for document in self.documents:
                print(document)

    def show_Moved_Pictures(self):

        print(f"{len(self.pictures)} Files moved to Pictures!")
        if self.flag.lower() == 'yes':
            for picture in self.pictures:
                print(picture)

    def show_Moved_Music(self):

        print(f"{len(self.musics)} Files moved to Music!")
        if self.flag.lower() == 'yes':
            for music in self.musics:
                print(music)
        
    def show_Moved_Videos(self):

        print(f"{len(self.videos)} Files moved to Videos!")
        if self.flag.lower() == 'yes':
            for video in self.videos:
                print(video)

    def show_Moved_Others(self):
    
        print(f"{len(self.others)} Files moved to Others!")
        if self.flag.lower() == 'yes':
            for other in self.others:
                print(other)


    # Functions Handling the Moving Mechanism

    def move_To_Document(self):

        destination = os.path.join(self.source, 'Documents')
        self.checkDirExists(destination)
        print("Moving Documents ...")
        for document in self.documents:
            shutil.move(os.path.join(self.source, document), destination)
        self.show_Moved_Documents()

    def move_To_Pictures(self):

        destination = os.path.join(self.source, 'Pictures')
        self.checkDirExists(destination)
        print("Moving Pictures ...")
        for picture in self.pictures:
            shutil.move(os.path.join(self.source, picture), destination)
        self.show_Moved_Pictures()

    def move_To_Music(self):

        destination = os.path.join(self.source, 'Music')
        self.checkDirExists(destination)
        print("Moving Music Files ...")
        for music in self.musics:
            shutil.move(os.path.join(self.source, music), destination)
        self.show_Moved_Music()

    def move_To_Videos(self):

        destination = os.path.join(self.source, 'Videos')
        self.checkDirExists(destination)
        print("Moving Video Files ...")
        for video in self.videos:
            shutil.move(os.path.join(self.source, video), destination)
        self.show_Moved_Videos()

    def move_To_Others(self):

        destination = os.path.join(self.source, 'Others')
        self.checkDirExists(destination)
        print("Moving Other File Extensions ...")
        for other in self.others:
            shutil.move(os.path.join(self.source, other), destination)
        self.show_Moved_Others()


    # Condition to Check if Required Files are Present [for Moving] and are Calling Appropriate Functions

    def checkCondition(self):

        ## Sets the Flag whether to Print the Files Names of the Moved Files
        self.flag = input("Do you want to Display the File Names? (YES/NO) : ")

        ## Check for whether the files exists for a Particular Category or Not

        if len(self.documents) != 0:
            self.move_To_Document()
        else:
            print("No Documents to Move!")

        if len(self.pictures) != 0:
            self.move_To_Pictures()
        else:
            print("No Pictures to Move!")

        if len(self.musics) != 0:
            self.move_To_Music()
        else:
            print("No Music Files to Move!")

        if len(self.videos) != 0:
            self.move_To_Videos()
        else:
            print("No Videos to Move!")

        if len(self.others) != 0:
            self.move_To_Others()
        else:
            print("No Miscellaneous Files to Move!")

    
    # Check for Existence of a Directory [if it DNE, creates a New One]
    
    def checkDirExists(self, path):

        if not os.path.isdir(path):
            os.makedirs(path)


# Main Function
def main():

    # Using Error Handling Techniques to Handle Error(s)
    
    try:

        print('''
Where do you want to Organise your Files?
1. Downloads
2. Any Other Location
Enter the Full Path to your Directory [Just Type 'Downloads' for Case 2] ->
        ''')
        path = input()
        moveFilesObject = directoryOrganiser(path)
        moveFilesObject.checkCondition()

    except:

        print("Please Try Again! An Unexpected Error has Occurred!")


# Main Method
if __name__ == '__main__':
    main()


# Importing Libraries

import shutil
from pathlib import Path
import os
from os import listdir
from os.path import isfile, join
import time


# Class 'Move Files'
class directoryOrganizer:

    # Constructor
    def __init__(self, path = None, verbose = False):

        # Checking Condition for Default Argument
        if not path:

            path = "Downloads"

            # Setting Home Directory Path
            self.homedir = str(Path.home())

            # Set the Source Directory Path [i.e the Downloads Path by DEFAULT]
            self.source = os.path.join(self.homedir, path)

        else:

            # Set the Source Directory Path [when Path isn't Downloads]
            self.source = os.path.join(path)

        # Copying All Files Names Present in the Source Directory
        self.all_files = [f for f in listdir(self.source) if isfile(join(self.source, f))]

        ## NOTE - We can Change the "/Downloads" path to any other appropriate path if this script is required to run in that Directory

        # List Containing the files to be Moved
        self.documents = []
        self.pictures = []
        self.musics = []
        self.videos = []
        self.others = []

        # Including All Types of File Extensions Possible

        ## Adding file extension in required places to include that files in that directory
        self.picture_ext = ['.jpeg', '.jpg', '.png', '.bnp', '.tiff', '.gif']
        self.document_ext = ['.txt', '.md', '.pdf', '.doc', '.odt', '.docx', '.xls', '.xlsx', '.csv', '.tex', '.ppt',
                             '.pptx', '.rtf', '.wpd']
        self.music_ext = ['.mp3', '.mpeg', '.wav', '.wma', '.3gp', '.aac', '.wma']
        self.video_ext = ['.mp4', '.avi', '.mkv', '.mov', '.flv']

        ## Adding CAPS Extensions too
        self.picture_ext += [i.upper() for i in self.picture_ext]
        self.document_ext += [i.upper() for i in self.picture_ext]
        self.music_ext += [i.upper() for i in self.music_ext]
        self.video_ext += [i.upper() for i in self.video_ext]

        # Flag if the User wants to Print the Files that are been moved
        self.flag = verbose

        # Extracting Information about the Files Present
        self.extractingFiles()

    # Function which extracts Information about the Files Present

    def extractingFiles(self):

        # Searching for Files and Categorising
        for files in self.all_files:

            if files.endswith(tuple(self.picture_ext)):
                self.pictures.append(files)
            elif files.endswith(tuple(self.document_ext)):
                self.documents.append(files)
            elif files.endswith(tuple(self.music_ext)):
                self.musics.append(files)
            elif files.endswith(tuple(self.video_ext)):
                self.videos.append(files)
            else:
                self.others.append(files)
        
        #### For Testing Purpose Only
        print(f"For Pictures : {len(self.pictures)}")
        print(f"For Documents : {len(self.documents)}")
        print(f"For Musics : {len(self.musics)}")
        print(f"For Videos : {len(self.videos)}")
        print(f"For Others : {len(self.others)}")


# Package Class
class organizer:

    # Constructor
    def __init__(self, path = None, verbose = False):

        # Intitialising Class Variables

        self.path = path
        self.verbose = verbose
        self.moveFilesObject = None                                      # Class Object

        # Using Error Handling Techniques to Handle Error(s)

        try:
            start = time.time()
            self.moveFilesObject = directoryOrganizer(self.path, self.verbose)
            # self.moveFilesObject.checkCondition()
            end = time.time()
            print('Time Elapsed : ', round(end - start, 2), 'seconds')

        except Exception as exception:

            print("Please Try Again! An Unexpected Error has Occurred!")
            print(f"Type : {type(exception)}")
            print(f"Error : {exception}")


# Main Method
if __name__ == '__main__':
    classObject = organizer('C:\Personal\Work\Directory Organiser\Test\Random', True)

## Conlusion => Unit Testing Successful for constructorCheck.


# Importing Class
from oopsImplementation import directoryOrganizer

# Importing Libraries
import time


# Package Class
class organizer:

    # Constructor
    def __init__(self, path = None, verbose = False):

        # Initialising Class Variables

        self.path = path
        self.verbose = verbose
        self.moveFilesObject = None  # Class Object

        # Using Error Handling Techniques to Handle Error(s)

        try:
            start = time.time()
            self.moveFilesObject = directoryOrganizer(self.path, self.verbose)
            self.moveFilesObject.checkCondition()
            end = time.time()
            print('Time Elapsed : ', round(end - start, 2), 'seconds')

        except Exception as exception:

            print("Please Try Again! An Unexpected Error has Occurred!")
            print(f"Type : {type(exception)}")
            print(f"Error : {exception}")

    # Method to Get Moved Files History
    def showHistory(self, extension_type = None):

        return self.moveFilesObject.showHistory(extension_type)


# Commenting out for Packaging.


# Main Method
if __name__ == '__main__':
    #path = 'C:\Personal\Work\Directory Organizer\Test\Random'
    #classObject = organizer(path, True)
    organizer('C:\\Users\\rahul.bordoloi\\Desktop\\123')
    #print(classObject.showHistory('Others'))






# Driver Program

import os
import shutil

file = 'C:\\Personal\\Work\\Directory Organiser\\temp.txt'
destination = 'C:\\Personal\\Work\\Directory Organiser\\Destination\\'

if not os.path.isdir(destination):
    os.makedirs(destination)
    print(f"New Folder Created in :{destination}")

shutil.move(file, destination)




# Importing Class
from oopsImplementation import directoryOrganiser

# Importing Libraries
import time


# Package Function
def organiser():

    # Using Error Handling Techniques to Handle Error(s)
    try:

        print('''
Where do you want to Organise your Files?
1. Downloads [System]
2. Any Other Location
Enter the Full Path to your Directory [Just Press ENTER for Case 1] ->''')
        path = input()
        start = time.time()
        moveFilesObject = directoryOrganiser(path)
        moveFilesObject.checkCondition()
        end = time.time()
        print('Time Elapsed : ', round(end - start, 2), 'seconds')

    except Exception as exception:

        print("Please Try Again! An Unexpected Error has Occurred!")
        print(f"Type : {type(exception)}")
        print(f"Error : {exception}")


# Commenting out for Packaging.
'''
# Main Method
if __name__ == '__main__':
    organiser()
'''


# Importing Libraries

import shutil
from pathlib import Path
import os
from os import listdir
from os.path import isfile, join

# Class `Directory Organizer`
class directoryOrganizer:

    # Constructor
    def __init__(self, path = None, verbose = False):

        # Checking Condition for Default Argument
        if not path:
            
            path = "Downloads"

            # Setting Home Directory Path
            self.homedir = str(Path.home())
            
            # Set the Source Directory Path [i.e the Downloads Path by DEFAULT]
            self.source = os.path.join(self.homedir, path)
        
        else:

            # Set the Source Directory Path [when Path isn't Downloads]
            self.source = os.path.join(path)
        
        # Copying All Files Names Present in the Source Directory
        self.all_files = [files for files in listdir(self.source) if isfile(join(self.source, files))]

        ## NOTE - We can change the "/Downloads" path to any other appropriate path if this script is required to run in that Directory

        # List Containing the files to be Moved
        self.documents = []
        self.pictures = []
        self.musics = []
        self.videos = []
        self.others = []

        # Including All Types of File Extensions Possible

        ## Adding file extensions in required places to include that files in that directory
        self.picture_ext = ['.jpeg', '.jpg', '.png', '.bnp', '.tiff', '.gif', '.raw', '.eps', '.bmp', '.nef']
        self.document_ext = ['.txt', '.md', '.pdf', '.doc', '.odt', '.docx', '.xls', '.xlsx', '.csv', '.tex', '.ppt', '.pptx', '.rtf', '.wpd']
        self.music_ext = ['.mp3', '.mpeg', '.wav', '.wma', '.3gp', '.aac', '.wma']
        self.video_ext = ['.mp4', '.avi', '.mkv', '.mov', '.flv']

        ## Adding CAPS Extensions too
        self.picture_ext += [i.upper() for i in self.picture_ext]
        self.document_ext += [i.upper() for i in self.picture_ext]
        self.music_ext += [i.upper() for i in self.music_ext]
        self.video_ext += [i.upper() for i in self.video_ext]

        # Flag if the User wants to Print the Output into the Console [Files that are been moved & its Status]
        self.flag = verbose

        # Dictionary to Keep Track of the Files Moved according to their Type
        self.historyDictionary = {}

        # Extracting Information about the Files Present
        self.extractingFiles()


    # Method which extracts Information about the Files Present

    def extractingFiles(self):

        # Searching for Files and Categorising
        for files in self.all_files:

            if files.endswith(tuple(self.picture_ext)):
                self.pictures.append(files)
            elif files.endswith(tuple(self.document_ext)):
                self.documents.append(files)
            elif files.endswith(tuple(self.music_ext)):
                self.musics.append(files)
            elif files.endswith(tuple(self.video_ext)):
                self.videos.append(files)
            else:
                self.others.append(files)


    # Display Method to Print Operation(s) [Show Moved Files] [Verbose]

    def printMovedFiles(self, datatype = 'Others'):

        # Initialising List of Files Items & Setting up their Type
        fileList = None

        if datatype == 'Documents':
            fileList = self.documents
        if datatype == 'Pictures':
            fileList = self.pictures
        if datatype == 'Musics':
            fileList = self.musics
        if datatype == 'Videos':
            fileList = self.videos
        elif datatype == 'Others':
            fileList = self.others

        # Prints the Output to the Console if `verbose` is True
        if self.flag:
            print(f'{len(fileList)} Files moved to {datatype}!')
            for file in fileList:
                print(file)


    # Method Handling the Moving Mechanism

    def moveFilesToDir(self, datatype = 'Others'):

        # Setting up Destination Directory according to Extension Type for Transfer
        destination = os.path.join(self.source, datatype)
        self.checkDirExists(destination)

        # File Move Initiation
        print(f"Moving {datatype[:-1]} File Extensions ...")

        # Initialising List of Files Items & Setting up their Type
        fileList = None

        if datatype == 'Documents':
            fileList = self.documents
        if datatype == 'Pictures':
            fileList = self.pictures
        if datatype == 'Musics':
            fileList = self.musics
        if datatype == 'Videos':
            fileList = self.videos
        elif datatype == 'Others':
            fileList = self.others

        # Moving the Files from Source to Destination
        for file in fileList:
            shutil.move(os.path.join(self.source, file), os.path.join(destination, file))

        # Print Moved Files into the Console if `verbose` is True
        if self.flag:
            self.printMovedFiles(datatype)


    # Method to Check if Required Files are Present [for Moving] and calling Appropriate Functions accordingly

    def checkCondition(self):

        ## Check for whether the files exists for a Particular Category type or Not

        if len(self.documents) != 0:
            self.moveFilesToDir('Documents')
        else:
            print("No Documents to Move!")

        if len(self.pictures) != 0:
            self.moveFilesToDir('Pictures')
        else:
            print("No Pictures to Move!")

        if len(self.musics) != 0:
            self.moveFilesToDir('Musics')
        else:
            print("No Music Files to Move!")

        if len(self.videos) != 0:
            self.moveFilesToDir('Videos')
        else:
            print("No Videos to Move!")

        if len(self.others) != 0:
            self.moveFilesToDir('Others')
        else:
            print("No Miscellaneous Files to Move!")

    
    # Method to check for Existence of a Directory [if it DNE, creates a New One]
    
    def checkDirExists(self, path):

        if not os.path.isdir(path):
            os.makedirs(path)


    # Method for Giving out the Dictionary of the Files Being Moved [History]

    def showHistory(self, extension_type = None):

        self.historyDictionary['Documents'] = self.documents
        self.historyDictionary['Pictures'] = self.pictures
        self.historyDictionary['Musics'] = self.musics
        self.historyDictionary['Videos'] = self.videos
        self.historyDictionary['Others'] = self.others

        if extension_type:
            return self.historyDictionary[extension_type]
        else:
            return self.historyDictionary




from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(

    name = 'directory_organizer',
    version = '1.0.3',
    description = 'Utility Package that organizes and moves the specific file types to its type Specific Directories',
    url = "https://github.com/rahulbordoloi/Directory-Organizer/",
    author = "Rahul Bordoloi",
    author_email = "rahulbordoloi24@gmail.com",
    maintainer = "Sourav Mazumdar",
    maintainer_email = "souravmzdr@gmail.com",

    py_modules = ['directory_organizer', 'oopsImplementation'],
    package_dir = {'': 'src'},

    classifiers = [
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Topic :: Utilities",
        "Natural Language :: English",
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Customer Service",
        "Intended Audience :: Developers",
        "Intended Audience :: End Users/Desktop"
    ],

    long_description = long_description,
    long_description_content_type = "text/markdown",

    extras_require = {
        "dev" : [
            "pytest >= 3.7",
        ],
    },
)